[prickly_cuvier] Nextflow Workflow Report
Author: Paolo Di Tommaso, Phil Ewels
Description: Nextflow workflow report for run id [prickly_cuvier]

# Nextflow workflow report

## `[prickly_cuvier]` (resumed run)

Workflow execution completed successfully!

Run times
  17-Feb-2021 16:18:59 - 17-Feb-2021 16:24:34 (duration: 5m 35s)

60 succeeded
0 cached
0 ignored
0 failed

Nextflow command

      nextflow run ../main.nf --input samplesheet.csv --genome false --scov2 true --freed -resume -profile docker --tree_extra_fasta sequences.fasta --tree --outdir results

CPU-Hours
  `0.3`
Launch directory
  `/home/test/test`
Work directory
  `/home/test/test/work`
Project directory
  `/home/test/.nextflow/assets/peterk87/nf-virontus`
Script name
  `main.nf`
Script ID
  `c85d4bcf33a29c90a08711b96f8fb456`
Workflow session
  `3827a203-6a1a-42a7-835d-da894f5fb241`
Workflow profile
  docker
Workflow container
  `peterk87/nf-virontus:2.0.0`
Container engine
  `docker`
Nextflow version
  version 20.10.0, build 5431 (01-11-2020 15:28 UTC)

## Resource Usage

These plots give an overview of the distribution of resource usage for each process.

#### CPU

#### Memory

#### Job Duration

#### I/O

## Tasks

This table shows information about each task in the workflow. Use the search box on the right to filter rows for specific values. Clicking headers will sort the table by that value and scrolling side to side will reveal more columns.

Values shown as:

(tasks table omitted because the dataset is too big)